@@ -7,7 +7,6 @@ Created on Thu Jan  7 11:33:00 2021
 from asammdf import MDF
 import pandas as pd
 import numpy as np
-from pathlib import Path
 
 class mdfSubset:  
         """        
@@ -34,7 +33,7 @@ class mdfSubset:
             """        
             Parameters
             ----------
-            filepath_MF4 : windowsPath / string
+            filepath_MF4 : string
                 either windowsPath or a string of full windows path of the file
             filepath_signalListCsv : csv
                 Must contain Columns [Name,Type,Signal]
@@ -46,12 +45,12 @@ class mdfSubset:
             TYPE
                 returns a list with signals extracted (listed in csv) from mf4 and filename
             """
-            filename = Path(filepath_MF4).name
+            filename = filepath_MF4.split('\\')[-1].split('.')[0]
             mf4data = MDF(filepath_MF4)
             signalCsv = pd.read_csv(filepath_signalListCsv)
             subsetList = []
             noSigMissing = 0
-            for signals in range(len(signalCsv)): #len(signalCsv iterate for all signal in the CSV
+            for signals in range(20): #len(signalCsv iterate for all signal in the CSV
                 try:                      
                     sg_pos=mf4data.whereis(signalCsv.Signal[signals])            
                     for k in range(len(sg_pos)): # valid group and channel selection
